@@ -194,8 +194,9 @@ fn main() -> Result<(), io::Error> {
                                 let chars = query.clone();
                                 let mut chars = chars.chars().rev();
                                 while let Some(c) = chars.next() {
-                                    if c == ' ' {
-                                        break;
+                                    match c {
+                                        ' ' | '-' | '_' => break,
+                                        _ => (),
                                     }
                                 }
                                 let chars = chars.rev().collect::<String>();
@@ -209,13 +210,14 @@ fn main() -> Result<(), io::Error> {
                         }
                     },
                     KeyCode::Enter => {
-                        (*results).borrow_mut().clear();
+                        results.borrow_mut().clear();
                         installed_cache.clear();
+                        info.borrow_mut().clear();
                         selected = 0;
                         let packages = search(&query);
 
                         for line in packages.lines().map(|line| line.to_string()) {
-                            (*results).borrow_mut().push(line);
+                            results.borrow_mut().push(line);
                         }
                         redraw = true;
                         mode = Mode::Select;
@@ -226,10 +228,10 @@ fn main() -> Result<(), io::Error> {
                     KeyCode::Up => {
                         if selected > 0 {
                             selected -= 1;
-                            (*info).borrow_mut().clear();
+                            info.borrow_mut().clear();
                         } else {
                             selected = results.borrow().len() as u16 - 1;
-                            (*info).borrow_mut().clear();
+                            info.borrow_mut().clear();
                         }
                         redraw = true;
                     }
@@ -237,10 +239,10 @@ fn main() -> Result<(), io::Error> {
                         let result_count = results.borrow().len();
                         if result_count > 1 && selected < result_count as u16 - 1 {
                             selected += 1;
-                            (*info).borrow_mut().clear();
+                            info.borrow_mut().clear();
                         } else {
                             selected = 0;
-                            (*info).borrow_mut().clear();
+                            info.borrow_mut().clear();
                         }
                         redraw = true;
                     }
@@ -249,7 +251,7 @@ fn main() -> Result<(), io::Error> {
 
                         if selected >= per_page && results.borrow().len() > per_page as usize {
                             selected -= per_page;
-                            (*info).borrow_mut().clear();
+                            info.borrow_mut().clear();
                             redraw = true;
                         }
                     }
@@ -261,7 +263,7 @@ fn main() -> Result<(), io::Error> {
                             && results.borrow().len() > per_page as usize
                         {
                             selected += per_page;
-                            (*info).borrow_mut().clear();
+                            info.borrow_mut().clear();
                             redraw = true;
                         }
                     }
@@ -269,10 +271,10 @@ fn main() -> Result<(), io::Error> {
                         'j' => {
                             if selected > 0 {
                                 selected -= 1;
-                                (*info).borrow_mut().clear();
+                                info.borrow_mut().clear();
                             } else {
                                 selected = results.borrow().len() as u16 - 1;
-                                (*info).borrow_mut().clear();
+                                info.borrow_mut().clear();
                             }
                             redraw = true;
                         }
@@ -280,10 +282,10 @@ fn main() -> Result<(), io::Error> {
                             let result_count = results.borrow().len();
                             if result_count > 1 && selected < result_count as u16 - 1 {
                                 selected += 1;
-                                (*info).borrow_mut().clear();
+                                info.borrow_mut().clear();
                             } else {
                                 selected = 0;
-                                (*info).borrow_mut().clear();
+                                info.borrow_mut().clear();
                             }
                             redraw = true;
                         }
@@ -293,7 +295,7 @@ fn main() -> Result<(), io::Error> {
 
                             if selected >= per_page && results.borrow().len() > per_page as usize {
                                 selected -= per_page;
-                                (*info).borrow_mut().clear();
+                                info.borrow_mut().clear();
                                 redraw = true;
                             }
                         }
@@ -305,7 +307,7 @@ fn main() -> Result<(), io::Error> {
                                 && results.borrow().len() > per_page as usize
                             {
                                 selected += per_page;
-                                (*info).borrow_mut().clear();
+                                info.borrow_mut().clear();
                                 redraw = true;
                             }
                         }
@@ -407,19 +409,19 @@ fn main() -> Result<(), io::Error> {
                             let result_count = results.borrow().len();
                             if result_count > 1 && selected < result_count as u16 - 1 {
                                 selected += 1;
-                                (*info).borrow_mut().clear();
+                                info.borrow_mut().clear();
                             } else {
                                 selected = 0;
-                                (*info).borrow_mut().clear();
+                                info.borrow_mut().clear();
                             }
                         }
                         MouseEventKind::ScrollUp => {
                             if selected > 0 {
                                 selected -= 1;
-                                (*info).borrow_mut().clear();
+                                info.borrow_mut().clear();
                             } else {
                                 selected = results.borrow().len() as u16 - 1;
-                                (*info).borrow_mut().clear();
+                                info.borrow_mut().clear();
                             }
                         }
                         _ => (),
@@ -522,16 +524,14 @@ fn get_info(query: String, index: usize, cache: &mut HashMap<usize, bool>) -> Ve
 fn is_installed(queries: Rc<Vec<String>>, skip: usize, cache: &mut HashMap<usize, bool>) {
     let mut cmd = std::process::Command::new("paru");
     cmd.arg("-Qq");
-    for q in queries.clone().iter() {
-        cmd.arg(q);
-    }
+    cmd.args(queries.clone().iter());
 
     let output = cmd.output().unwrap().stdout;
     let output = String::from_utf8(output).unwrap();
     let mut index;
     for (i, query) in queries.iter().enumerate() {
         index = i + skip;
-        if cache.contains_key(&(index)) {
+        if cache.contains_key(&index) {
             continue;
         }
         let is_installed = output.contains(&(query.to_owned() + "\n"));
